@@ -1,21 +1,11 @@
 use super::*;
 
 impl ForeignKeyBuilder for PostgresQueryBuilder {
-    fn prepare_foreign_key_create_statement(&self, create: &ForeignKeyCreateStatement, sql: &mut SqlWriter) {
-        self.prepare_foreign_key_create_statement_internal(create, sql, false)
-    }
-
-    fn prepare_foreign_key_action(&self, foreign_key_action: &ForeignKeyAction, sql: &mut SqlWriter) {
-        write!(sql, "{}", match foreign_key_action {
-            ForeignKeyAction::Restrict => "RESTRICT",
-            ForeignKeyAction::Cascade => "CASCADE",
-            ForeignKeyAction::SetNull => "SET NULL",
-            ForeignKeyAction::NoAction => "NO ACTION",
-            ForeignKeyAction::SetDefault => "SET DEFAULT",
-        }).unwrap()
-    }
-
-    fn prepare_foreign_key_drop_statement(&self, drop: &ForeignKeyDropStatement, sql: &mut SqlWriter) {
+    fn prepare_foreign_key_drop_statement(
+        &self,
+        drop: &ForeignKeyDropStatement,
+        sql: &mut SqlWriter,
+    ) {
         write!(sql, "ALTER TABLE ").unwrap();
         if let Some(table) = &drop.table {
             table.prepare(sql, '"');
@@ -26,10 +16,13 @@ impl ForeignKeyBuilder for PostgresQueryBuilder {
             write!(sql, "\"{}\"", name).unwrap();
         }
     }
-}
 
-impl PostgresQueryBuilder {
-    pub(crate) fn prepare_foreign_key_create_statement_internal(&self, create: &ForeignKeyCreateStatement, sql: &mut SqlWriter, inside_table_creation: bool) {
+    fn prepare_foreign_key_create_statement_internal(
+        &self,
+        create: &ForeignKeyCreateStatement,
+        sql: &mut SqlWriter,
+        inside_table_creation: bool,
+    ) {
         if !inside_table_creation {
             write!(sql, "ALTER TABLE ").unwrap();
             if let Some(table) = &create.foreign_key.table {
@@ -60,13 +53,17 @@ impl PostgresQueryBuilder {
         write!(sql, " ").unwrap();
 
         write!(sql, "(").unwrap();
-        create.foreign_key.ref_columns.iter().fold(true, |first, col| {
-            if !first {
-                write!(sql, ", ").unwrap();
-            }
-            col.prepare(sql, '"');
-            false
-        });
+        create
+            .foreign_key
+            .ref_columns
+            .iter()
+            .fold(true, |first, col| {
+                if !first {
+                    write!(sql, ", ").unwrap();
+                }
+                col.prepare(sql, '"');
+                false
+            });
         write!(sql, ")").unwrap();
 
         if let Some(foreign_key_action) = &create.foreign_key.on_delete {
@@ -79,4 +76,4 @@ impl PostgresQueryBuilder {
             self.prepare_foreign_key_action(&foreign_key_action, sql);
         }
     }
-}
\ No newline at end of file
+}
