@@ -1,7 +1,7 @@
+pub(crate) mod foreign_key;
+pub(crate) mod index;
 pub(crate) mod query;
 pub(crate) mod table;
-pub(crate) mod index;
-pub(crate) mod foreign_key;
 
 use super::*;
 
@@ -15,9 +15,8 @@ impl Default for SqliteQueryBuilder {
     }
 }
 
-impl GenericBuilder for SqliteQueryBuilder {
-    type QueryBuilder = Self;
-    type TableBuilder = Self;
-    type IndexBuilder = Self;
-    type ForeignKeyBuilder = Self;
-}
\ No newline at end of file
+impl GenericBuilder for SqliteQueryBuilder {}
+
+impl SchemaBuilder for SqliteQueryBuilder {}
+
+impl QuotedBuilder for SqliteQueryBuilder {}
