@@ -1191,6 +1191,12 @@ impl SelectStatement {
         self
     }
 
+    /// Reset limit
+    pub fn reset_limit(&mut self) -> &mut Self {
+        self.limit = None;
+        self
+    }
+
     /// Offset number of returned rows.
     ///
     /// # Examples
@@ -1222,6 +1228,12 @@ impl SelectStatement {
         self.offset = Some(Value::BigUnsigned(offset));
         self
     }
+
+    /// Reset offset
+    pub fn reset_offset(&mut self) -> &mut Self {
+        self.offset = None;
+        self
+    }
 }
 
 impl QueryStatementBuilder for SelectStatement {
